@@ -4,15 +4,15 @@
 enum keyWords
 {
     UNKNOWN = '?',            // for getopt
-    ABOVE, ABSOLUTE, ALIGN, ANCIENT, ARC_COLOR, ARC_FILE, AUTO, AZIMUTHAL, 
-    BACKGROUND, BASEMAG, BELOW, BODY, BONNE, 
+    ABOVE, ABSOLUTE, ALIGN, ANCIENT, ARC_COLOR, ARC_FILE, ARC_SPACING, AUTO, AZIMUTHAL, 
+    BACKGROUND, BASEMAG, BELOW, BODY, BONNE, BUMP_MAP, BUMP_SCALE, 
     CENTER, CIRCLE, CLOUD_GAMMA, CLOUD_MAP, CLOUD_SSEC, CLOUD_THRESHOLD, COLOR, CONFIG_FILE, 
     DATE, DATE_FORMAT, DAY_MAP, DELIMITER, DRAW_ORBIT, DYNAMIC_ORIGIN,
     ENDOFLINE, EPHEMERIS, 
     FONT, FONTSIZE, FORK, FOV, 
-    GALACTIC, GEOMETRY, GNOMONIC, GRID, GRID1, GRID2, GRID_COLOR, GROUND, 
+    GALACTIC, GEOMETRY, GLARE, GNOMONIC, GRID, GRID1, GRID2, GRID_COLOR, GROUND, GRS_LON,
     HEMISPHERE, HIBERNATE,
-    IDLEWAIT, IMAGE, INTERPOLATE_ORIGIN_FILE,
+    ICOSAGNOMONIC, IDLEWAIT, IMAGE, INTERPOLATE_ORIGIN_FILE,
     JDATE, JPL_FILE, 
     LABEL, LABELPOS, LABEL_STRING, LAMBERT, LANGUAGE, LATITUDE, LATLON, LBR, LEFT, LIGHT_TIME, LOCALTIME, LOGMAGSTEP, LONGITUDE, LOOKAT, 
     MAGNIFY, MAJOR, MAKECLOUDMAPS, MAP_BOUNDS, MARKER_BOUNDS, MARKER_COLOR, MARKER_FILE, MARKER_FONT, MARKER_FONTSIZE, MAX_RAD_FOR_LABEL, MIN_RAD_FOR_LABEL, MIN_RAD_FOR_MARKERS, MERCATOR, MOLLWEIDE, MULTIPLE,
@@ -33,15 +33,15 @@ enum keyWords
 const char * const keyWordString[LAST_WORD] =
 {
     "UNKNOWN",
-    "ABOVE", "ABSOLUTE", "ALIGN", "ANCIENT", "ARC_COLOR", "ARC_FILE", "AUTO", "AZIMUTHAL", 
-    "BACKGROUND", "BASEMAG", "BELOW", "BODY", "BONNE", 
+    "ABOVE", "ABSOLUTE", "ALIGN", "ANCIENT", "ARC_COLOR", "ARC_FILE", "ARC_SPACING", "AUTO", "AZIMUTHAL", 
+    "BACKGROUND", "BASEMAG", "BELOW", "BODY", "BONNE", "BUMP_MAP", "BUMP_SCALE", 
     "CENTER", "CIRCLE", "CLOUD_GAMMA", "CLOUD_MAP", "CLOUD_SSEC", "CLOUD_THRESHOLD", "COLOR", "CONFIG_FILE", 
     "DATE", "DATE_FORMAT", "DAY_MAP", "DELIMITER", "DRAW_ORBIT", "DYNAMIC_ORIGIN",
     "ENDOFLINE", "EPHEMERIS", 
     "FONT", "FONTSIZE", "FORK", "FOV", 
-    "GALACTIC", "GEOMETRY", "GNOMONIC", "GRID", "GRID1", "GRID2", "GRID_COLOR", "GROUND", 
+    "GALACTIC", "GEOMETRY", "GLARE", "GNOMONIC", "GRID", "GRID1", "GRID2", "GRID_COLOR", "GROUND", "GRS_LON", 
     "HEMISPHERE", "HIBERNATE",
-    "IDLEWAIT", "IMAGE", "INTERPOLATE_ORIGIN_FILE",
+    "ICOSAGNOMONIC", "IDLEWAIT", "IMAGE", "INTERPOLATE_ORIGIN_FILE",
     "JDATE", "JPL_FILE", 
     "LABEL", "LABELPOS", "LABEL_STRING", "LAMBERT", "LANGUAGE", "LATITUDE", "LATLON", "LBR", "LEFT", "LIGHT_TIME", "LOCALTIME", "LOGMAGSTEP", "LONGITUDE", "LOOKAT", 
     "MAGNIFY", "MAJOR", "MAKECLOUDMAPS", "MAP_BOUNDS", "MARKER_BOUNDS", "MARKER_COLOR", "MARKER_FILE", "MARKER_FONT", "MARKER_FONTSIZE", "MAX_RAD_FOR_LABEL", "MIN_RAD_FOR_LABEL", "MIN_RAD_FOR_MARKERS", "MERCATOR", "MOLLWEIDE", "MULTIPLE",
