@@ -35,8 +35,8 @@ calculateSatellitePosition(time_t tv_sec, const int id,
     if (options->LightTime())
     {
         double tX, tY, tZ;
-        double jd = options->getJulianDay();
-        if (options->UniversalTime()) jd += delT(jd) / 86400;
+        double jd = options->JulianDay();
+
         Planet earth(jd, EARTH);
         earth.calcHeliocentricEquatorial();
         earth.getPosition(tX, tY, tZ);
@@ -149,14 +149,14 @@ readSatelliteFile(const char *line, Planet *planet,
             break;
         case CIRCLE:
         {
-	    checkLocale(LC_NUMERIC, "C");
+            checkLocale(LC_NUMERIC, "C");
             double angle;
             sscanf(returnString, "%lf", &angle);
             if (angle < 0) angle *= -1;
             if (angle > 90) angle = 90;
             angle = 90 - angle;
             altcirc.push_back(angle * deg_to_rad);
-	    checkLocale(LC_NUMERIC, "");
+            checkLocale(LC_NUMERIC, "");
         }
         break;
         case COLOR:
@@ -217,7 +217,7 @@ readSatelliteFile(const char *line, Planet *planet,
             name.assign(returnString);
             break;
         case SPACING:
-	    checkLocale(LC_NUMERIC, "C");
+            checkLocale(LC_NUMERIC, "C");
             sscanf(returnString, "%lf", &spacing);
             if (spacing < 0) 
             {
@@ -225,7 +225,7 @@ readSatelliteFile(const char *line, Planet *planet,
                 spacing = 0.1;
                 syntaxError = true;
             }
-	    checkLocale(LC_NUMERIC, "");
+            checkLocale(LC_NUMERIC, "");
             break;
         case TRAIL:
         {
@@ -334,8 +334,8 @@ readSatelliteFile(const char *line, Planet *planet,
     // with the same satellite.
     satellite->loadTLE();
 
-    time_t startTime = static_cast<time_t> (options->getTVSec() + trailStart * 60);
-    time_t endTime = static_cast<time_t> (options->getTVSec() + trailEnd * 60);
+    time_t startTime = static_cast<time_t> (options->TVSec() + trailStart * 60);
+    time_t endTime = static_cast<time_t> (options->TVSec() + trailEnd * 60);
     time_t interval = static_cast<time_t> (trailInterval * 60);
 
     if (startTime > endTime)
@@ -366,7 +366,7 @@ readSatelliteFile(const char *line, Planet *planet,
                 planet, view, projection, annotationMap);
     }
 
-    satellite->getSpherical(options->getTVSec(), lat, lon, rad);
+    satellite->getSpherical(options->TVSec(), lat, lon, rad);
     if (trailType == GROUND) rad = 1;
 
     double X, Y, Z;
